pub struct Button { /* private fields */ }Expand description
A styled button component
Implementations
Sourceimpl Button
impl Button
Sourcepub fn new(id: impl Into<ElementId>, label: impl Into<SharedString>) -> Self
pub fn new(id: impl Into<ElementId>, label: impl Into<SharedString>) -> Self
Create a new button with a label
Sourcepub fn variant(self, variant: ButtonVariant) -> Self
pub fn variant(self, variant: ButtonVariant) -> Self
Set the button variant
Sourcepub fn size(self, size: ButtonSize) -> Self
pub fn size(self, size: ButtonSize) -> Self
Set the button size
Sourcepub fn full_width(self, full_width: bool) -> Self
pub fn full_width(self, full_width: bool) -> Self
Make button full width
Sourcepub fn icon_left(self, icon: impl Into<SharedString>) -> Self
pub fn icon_left(self, icon: impl Into<SharedString>) -> Self
Add an icon to the left of the label
Sourcepub fn icon_right(self, icon: impl Into<SharedString>) -> Self
pub fn icon_right(self, icon: impl Into<SharedString>) -> Self
Add an icon to the right of the label
Sourcepub fn theme(self, theme: ButtonTheme) -> Self
pub fn theme(self, theme: ButtonTheme) -> Self
Set custom theme colors