Menu components - MenuItem, Menu, MenuBar, and ContextMenu
Provides a complete menu system for application navigation and context menus.
Structs
- Menu
- A dropdown menu containing menu items
- MenuBar
- A horizontal menu bar
- Menu
BarItem - A menu bar item (top-level menu)
- Menu
Item - A single menu item
Functions
- menu_
bar_ button - Helper to build a single menu bar button without handlers Use this when you need to add cx.listener() handlers