pub struct Divider { /* private fields */ }Expand description
A divider line
Implementations
Sourceimpl Divider
impl Divider
Sourcepub fn id(self, id: impl Into<SharedString>) -> Self
pub fn id(self, id: impl Into<SharedString>) -> Self
Set an ID for the divider (required for interactive dividers)
Sourcepub fn hover_color(self, color: Rgba) -> Self
pub fn hover_color(self, color: Rgba) -> Self
Set hover color (for interactive dividers)
Sourcepub fn interactive(self) -> Self
pub fn interactive(self) -> Self
Make this an interactive resize divider
Sourcepub fn build(self) -> Stateful<Div>
pub fn build(self) -> Stateful<Div>
Build into a stateful element that can have handlers attached Use this when you need to add event handlers (e.g., for resize dividers)
Sourcepub fn build_simple(self) -> Div
pub fn build_simple(self) -> Div
Build into a non-stateful element (for simple visual dividers)